@@ -10,7 +10,7 @@ from grtoolkit.PowerPoint import duplicate_slide
 # parent = dirname(sys.argv[0])
 parent = os.getcwd()
 QUOTES = f'{parent}\\Quotes.txt'
-OLD_PPT = f'{parent}\\QUOTE_TEMPLATE.pptm'
+OLD_PPT = f'{parent}\\QUOTE_PPT_TEMPLATE.pptm'
 NEW_PPT = f'{parent}\\QUOTE_NEW.pptm'
 
 prs = Presentation(OLD_PPT)
